#
# spec file for package xdm
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1230
%define with_systemd 1
%else
%define with_systemd 0
%endif

%define _dminitdir %{_libexecdir}/X11/displaymanagers

%if 0%{?suse_version} < 01210
%define dm_fallbacks 1
%else
%define dm_fallbacks 0
%endif

Name:           xdm
Version:        1.1.11
Release:        11.1
Summary:        X Display Manager
License:        MIT
Group:          System/X11/Utilities
Url:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.bz2
Source1:        xdm.tar.bz2
Source2:        HOWTO.xdm
Source3:        xdm-fallbacks.tar.bz2
Source4:        display-manager.service
Source5:        xsession.desktop
%if !%with_systemd
Patch0:         xdm-consolekit.diff
%endif
Patch1:         xdm-tolerant-hostname-changes.diff
%if 0%{?suse_version} >= 01140 && 0%{?suse_version} < 1320
# Needed to create the man page symlink to init.d
BuildRequires:  aaa_base-extras
%endif
# needed for patch0, patch2, patch3, patch4
BuildRequires:  libtool
BuildRequires:  pam-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xau)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xdmcp)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.4
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(xtrans)
%if !%with_systemd
BuildRequires:  ConsoleKit-devel
Requires:       ConsoleKit
%else
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
%endif
Requires:       /sbin/pidof
Requires:       logrotate
Requires:       sessreg
Requires:       xconsole
Requires:       xli
Requires:       xmessage
Requires:       xrdb
Requires:       xset
Requires:       xsetroot
%if 0%{?suse_version} > 1320
Requires:       xterm-bin
%else
Requires:       xterm
%endif
Recommends:     dbus-1-x11
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%if !%with_systemd
%define _unitdir /usr/lib/systemd/system
%endif

%description
Xdm manages a collection of X displays, which may be on the local host
or remote servers.

%package xsession
Summary:        User/System Xsession Desktop File
Group:          System/X11/Utilities
Requires:       xdm
Supplements:    xdm

%description xsession
This package contains the System desktop file which will cause 
the execution of a user provided $HOME/.xsession script or pick 
the system wide DM default set in /etc/sysconfig/displaymanager.

%prep
%setup -q
cp %{SOURCE2} .
%if !%with_systemd
%patch0 -p1
%endif
pushd xdm
%patch1 -p1
popd

%build
# needed for patch0
autoreconf -fi
%configure \
        --disable-static \
        --with-pam \
        --with-xdmconfigdir=%{_sysconfdir}/X11/xdm \
        --with-xdmscriptdir=%{_sysconfdir}/X11/xdm \
	--with-systemdsystemunitdir=no
make %{?_smp_mflags}

%install
%make_install
# Not used anymore by SuSE
rm %{buildroot}%{_sysconfdir}/X11/xdm/{GiveConsole,TakeConsole,Xsetup_0}

pushd %{buildroot}
# SuSE default XDM configuration
tar xf %{SOURCE1}
%if %dm_fallbacks
tar xf %{SOURCE3}
%endif
%ifarch s390 s390x
sed -i -e "s+DISPLAYMANAGER_REMOTE_ACCESS=.*+DISPLAYMANAGER_REMOTE_ACCESS=\"yes\"+g" \
       -e "s+DISPLAYMANAGER_STARTS_XSERVER=.*+DISPLAYMANAGER_STARTS_XSERVER=\"no\"+g" \
    var/adm/fillup-templates/sysconfig.displaymanager
%endif
popd

# Correct location (FHS-2.1)
ln -s %{_localstatedir}/lib/xdm/authdir %{buildroot}%{_sysconfdir}/X11/xdm/authdir
# bnc#223734
rm %{buildroot}%{_libdir}/X11/xdm/libXdmGreet.la
# for FHS compliance (bnc#21857)
mv %{buildroot}%{_libdir}/X11/xdm/chooser %{buildroot}%{_bindir}
# fdo#35868 (closed INVALID, but because of above fix, we want it)
ln -s xdm.1%{?ext_man} %{buildroot}%{_mandir}/man1/chooser.1%{?ext_man}
%__install -D %{S:5} -m 0644 %{buildroot}%{_datadir}/xsessions/xsession.desktop
%if 0%{?suse_version} < 1315
# missing manual page
mkdir -p %{buildroot}%{_mandir}/man8
ln -s ../man7/init.d.7%{?ext_man} %{buildroot}%{_mandir}/man8/rcxdm.8%{?ext_man}
ln -sf %{_sysconfdir}/init.d/xdm %{buildroot}%{_sbindir}/rcxdm
%else
rm -f %{buildroot}%{_sbindir}/rcxdm
%__install -D %{S:4} -m 0444 %{buildroot}%{_unitdir}/display-manager.service
ln -sf service %{buildroot}%{_sbindir}/rcdisplay-manager
cat > %{buildroot}%{_sbindir}/rcxdm <<-'EOF'
	#!/bin/bash
	exec -a rcdisplay-manager %{_sbindir}/rcdisplay-manager ${1+"$@"}
	EOF
chmod 0755 %{buildroot}%{_sbindir}/rcxdm
%endif

%post
%if 0%{?suse_version} < 1315
%{fillup_and_insserv -Y xdm}
%else
%service_add_post display-manager.service
%endif
%{fillup_only -n displaymanager}

%pre
%if !0%{?suse_version} < 1315
  %service_add_pre display-manager.service
%endif

%postun
%if 0%{?suse_version} < 1315
%{insserv_cleanup}
%else
# Do not restart DM on update (bnc#886641)
%service_del_postun -n display-manager.service
%endif

%preun
%if !0%{?suse_version} < 1315
  %service_del_preun display-manager.service
%endif

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README
%doc HOWTO.xdm
%dir %{_dminitdir}
%{_dminitdir}/xdm
%if %dm_fallbacks
%{_dminitdir}/entrance.fallback
%{_dminitdir}/gdm.fallback
%{_dminitdir}/kdm.fallback
%{_dminitdir}/lxdm.fallback
%{_dminitdir}/slim.fallback
%{_dminitdir}/wdm.fallback
%endif
%config %{_sysconfdir}/X11/xdm/
%config(noreplace) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/xdmcp
%if 0%{?suse_version} < 1315
%{_sysconfdir}/init.d/xdm
%exclude %{_libexecdir}/X11/display-manager
%else
%exclude %{_sysconfdir}/init.d/xdm
%{_unitdir}/display-manager.service
%{_libexecdir}/X11/display-manager
%endif
%config %{_sysconfdir}/logrotate.d/xdm
%config %{_sysconfdir}/pam.d/xdm
%config %{_sysconfdir}/pam.d/xdm-np
%dir %{_localstatedir}/lib/xdm/
%{_localstatedir}/adm/fillup-templates/sysconfig.displaymanager
%{_localstatedir}/lib/xdm/authdir/
%ghost %{_localstatedir}/log/xdm.errors
%{_bindir}/chooser
%{_bindir}/xdm
%{_sbindir}/rcxdm
%if 0%{?suse_version} >= 1315
%{_sbindir}/rcdisplay-manager
%endif
%{_libdir}/X11/xdm/
%dir %{_datadir}/X11/app-defaults
%{_datadir}/X11/app-defaults/Chooser
%{_mandir}/man1/chooser.1%{?ext_man}
%{_mandir}/man1/xdm.1%{?ext_man}
%if 0%{?suse_version} < 1315
%{_mandir}/man8/rcxdm.8%{?ext_man}
%endif
%ifnarch %ix86
%dir %{_libdir}/X11
%endif

%files xsession
%dir %{_datadir}/xsessions
%{_datadir}/xsessions/xsession.desktop

%changelog
* Fri May  6 2016 eich@suse.com
- Make SUSEconfig handler for DISPLAYMANAGER_XSERVER_TCP_PORT_6000_OPEN
  robust against changes to the default setting of -listen/-nolisten tcp
  (boo#978262).
* Wed May  4 2016 eich@suse.com
- Prevent xdm.service from being built. We've got display-manager.service
  instead (bsc#978458).
* Wed Mar 30 2016 eich@suse.com
- xsession.desktop file:
  * created xsession sub-package for this file.
  * changed descriptive message to "User/System Default"
  (boo#971852).
* Wed Mar 30 2016 eich@suse.com
- xdm.tar.bz:
  Fixed Xsession script to cull the locale form the arguments before
  passing them on (boo#973045).
* Thu Mar  3 2016 eich@suse.com
- After boo#968405 got fixed in /etc/rpm/macros.systemd, resurrect the old
  behavior of %%postun (boo#968405).
* Sat Feb 27 2016 eich@suse.com
- xdm.tar.bz:
  * /etc/X11/xdm/sys.xsession:
    fix regression from fix for boo#967002 (boo#968172).
  * /etc/X11/xdm/Xsession:
    + Add comments for documentation
    + Fix semantics
    + Don't use $HOME/.xinitrc as session script. Let sys.xession
    handle this.
    + Make argument parser more robust:
    add parse error detection.
  * Add an 'xsession' desktop file: this should offer a session
    where the $HOME/.xsession is used (boo#968631).
* Fri Feb 26 2016 eich@suse.com
- Remove %%service_del_postun display-manager.service
  from %%postun macro (boo#968405).
* Wed Feb 17 2016 werner@suse.de
- Touch /etc/X11/xdm/sys.xsession for boo#967002 that is simply
  add attachment #66582 by using GNUPGHOME variable.
* Wed Feb 17 2016 eich@suse.com
- xdm.tar.bz2:
  * Test for the presence of $HOME/.gnupg/gpg-agent.conf before
    attemting to access it (boo#967002).
- xdm.spec:
  * Fix %%suse_version checking to work on Leap 42.1 as well.
* Wed Nov  4 2015 eich@suse.com
- rename SuSEconfig.xdm
  * /etc/X11/xdm/SuSEconfig.xdm -> /etc/X11/xdm/SUSEconfig.xdm
  * created a symlink for the old file (bsc#953563).
* Fri Oct 16 2015 dimstar@opensuse.org
- Fix the same TakeDevice racing bug also in /etc/init.d/xdm, which
  is an almost exact copy of /usr/lib/X11/display-manager.
- Set the installation of the systemd based service again to be
  valid on Leap (thus, in fact, not really caring for the bug in
  /etc/init.d/xdm).
* Wed Oct  7 2015 dimstar@opensuse.org
- Fix display-manager wrapper: only call TakeDevices in case $DM
  actually fails to start. This was the reason why gdm often failed
  to start with permission denied (depending on timing, gdm might
  fired up X before TakeDevices passed, X would receive the tty7
  by means of logind and TakeDevices reset the permissions again)
  (boo#939594).
* Mon Sep 14 2015 dimstar@opensuse.org
- display-manager.service: require and conflict getty@tty7.service:
  this is copied from gdm.service and is hopefully helping with
  the race condition, where X is often not able to start up on
  VT7 due to missing permissions. (boo#939594)
* Tue Aug  4 2015 eich@suse.com
- Replaced font resources for login screen with font face names.
  Since xdm is now built with Xft support, it uses face names for
  client side rendered fonts. The settings for screen widths >= 800
  are the xdm defaults. For smaller screens the sizes are reduced
  so they fit the screen better (bsc#940263).
* Sat Aug  1 2015 eich@suse.com
- Avoid confusion of user: add '-' to font names in etc/X11/xdm/Xresources.
  This is not required for the font names used in the file but some others.
  (bsc#940263).
* Fri Jul 31 2015 sndirsch@suse.com
- display-manager: don't try to kill DM if it's no longer running
  (bsc#939843)
* Wed Jul 29 2015 werner@suse.de
- Add some used programs to the requirement of xdm
- Use xli aka xsetbg if xpmroot is not available (hint from
  jemoreno@novell.com)
* Mon Jul 20 2015 sndirsch@suse.com
- rename README.SuSE file to README.SUSE (bnc#938737, FATE#316521)
* Tue Mar 17 2015 dvlaeev@suse.com
- We do have graphics on Power with KVM, so remove ppc64le from
  changing displaymanager sysconfig
* Thu Jan 29 2015 sndirsch@suse.com
- /etc/X11/xdm/keytable"
  * improved warning message, when mapping for console keyboard
    doesn't exist (bnc#914880)
* Sun Jan 18 2015 opensuse.lietuviu.kalba@gmail.com
- Don't truncate filenames of lt.baltic.map.gz, lt.std.map.gz,
  lt.l4.map.gz and defkeymap_V1.0 too much (bnc#897803).
* Wed Dec 17 2014 dimstar@opensuse.org
- On openSUSE > 13.2, xterm has been split into xterm-bin for the
  program and xterm for the app launcher. We only need the program,
  so conditionall Require xterm-bin.
* Mon Dec 15 2014 Led <ledest@gmail.com>
- fix bashisms in /etc/X11/xdm/* scripts
* Wed Dec  3 2014 gber@opensuse.org
- unset TMPDIR before executing the final user scripts/shell
  (boo#907041)
- start a login shell when using lksh/mksh
* Wed Oct  8 2014 werner@suse.de
- Use the option (--)enable-ssh-support of the gpg-agent if the
  user has configured this (boo#899647)
* Thu Oct  2 2014 sndirsch@suse.com
- sysconfig.displaymanager/DM list: added lightdm,sddm; removed
  kdm3,kdm4 (bnc#898876)
* Tue Aug  5 2014 sndirsch@suse.com
- replaced 'Also=' by 'Alias=' in display-manager.service
  (bnc#890413)
- make sure not to restart DM on package update; remove confusing
  comment about no longer existing %%%%stop_on_removal,
  %%restart_on_update macros from specfile (bnc#886641)
* Tue Jul 15 2014 sndirsch@suse.com
- udpate to release 1.1.11
- refreshed xdm-tolerant-hostname-changes.diff, xdm-consolekit.diff
- supersedes the following patches:
  U_xdm_config-AC_LIBTOOL_DLOPEN-is-required-for-dynamic-lin.patch,
  U_xdm_Fix-missing-linking-dependency-on-ldl.patch,
  U_xdm_config-use-libtool-export-dynamic-option-for-reverse.patch
* Wed May 28 2014 fcrozat@suse.com
- Use KillMode=process for systemd service, this ensures Xorg won't
  receive SIGKILL while switching to runlevel 3 [bnc#871808].
- Add "Also=xdm.service" to display-manager.service to better
  handle migration.
* Fri May 23 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Thu May 15 2014 arichardson.kde@gmail.com
- Don't run dbus-launch if the socket /run/user/<uid>/bus exists, since
  this means that dbus is already handled by systemd
* Tue May 13 2014 coolo@suse.com
- just don't "package" pid file. It's called xdm.pid, so it's pretty
  obvious what package it is from
- take the pid file out of the xdm.tar
* Mon Mar 24 2014 sndirsch@suse.com
- DISPLAYMANAGER_STARTS_XSERVER needs to be set to "no" on s390x
  and ppc64le (bnc#869267)
* Fri Mar 21 2014 werner@suse.de
- Move forward to systemd, that is use a real service unit file  (bnc#869260)
* Wed Mar  5 2014 cxiong@suse.com
- Add support for in-line environment variable settings
  Handling case like:
  Exec=env GNOME_SHELL_SESSION_MODE=classic gnome --session gnome-classic
  For now, this is only needed to fix session management issue as in bnc#863709.
* Wed Mar  5 2014 cxiong@suse.com
- fix two array iteration bug in etc/X11/xdm/Xsession (xdm.tar.bz2)
  1. "${#argv[@]}" is just the size of the array instead of all the elements,
    i.e. "${argv[@]}", no sharp "#" sign.
  2. index of array starting from 0, so "argc" should be increased at the end
    of iteration loop. (bnc#866874)
* Wed Feb 19 2014 sndirsch@suse.com
- /etc/X11/xdm/keytable: make use of systemd's localectl to
  generate Xserver's configuration snippet for keyboard layout;
  rely on systemd's kbd --> X keyboard mapping; the old mapping
  table originating from SaX2 is no longer being used (bnc#861819)
* Tue Feb 11 2014 dliang@suse.com
- Change the default /etc/X11/xdm/Xsession, (fate#316129)
  don't save standard output information to ~/.xsession-errors
  Modify the xdm.tar.bz2
* Tue Feb  4 2014 coolo@suse.com
- /etc/X11/xdm/RunChooser calls pidof, so require it
* Wed Jan  8 2014 lnussel@suse.de
- don't set twm as hardcoded default if DEFAULT_WM is empty, rely on
  the detection in xinitrc.common instead
* Mon Dec  2 2013 sndirsch@suse.com
- removed u_xdm-sig11-bug-598422.diff
  * problem has been resolved differently
* Fri Oct 18 2013 ferenc.gm@gmail.com
- Added support for qiv in /etc/X11/xdm/Xsetup
* Mon Sep 16 2013 sndirsch@suse.com
- fixed typo in /etc/X11/xdm/Xsetup
* Mon Sep 16 2013 sndirsch@suse.com
- fixed loading of .xkb files (bnc#840408)
* Tue Aug 13 2013 sndirsch@suse.com
- adjusted u_xdm-sig11-bug-598422.diff for openSUSE 12.2 build
  (which still applies xdm-consolekit.diff)
* Mon Jul 29 2013 sndirsch@suse.com
- u_xdm-sig11-bug-598422.diff
  * fix Sig11 in xdm when pressing Ctr-c (bnc#598422, bnc#831870)
* Fri Jun  7 2013 werner@suse.de
- Add some GNOME specifiv magics to Xsession to allow that ~/.i18n
  is always sourced (bnc#567324)
* Fri May 24 2013 werner@suse.de
- Some shells do not know about HOSTNAME variable and print error
  messages therefore export this variable
- Make check for dbus smart, that is check if threre is already
  an active session and use this if possible
- Be aware that one user may use several X sessions in parallel
  on the same system as well as on several systems with HOME on
  an NFS based share. That is do not override ~/.xsession-errors
* Thu Apr 11 2013 sndirsch@suse.com
- do not use '-k' option for checkproc for ssh-agent since
  /proc/<pid>/exe link is apparently not readable by the user
  used for that program (bnc#812783)
* Fri Mar  1 2013 fcrozat@suse.com
- Add systemd-user-sessions to xdm initscript X-Should-Start, to
  ensure user login is available when xdm is started.
* Fri Mar  1 2013 sndirsch@suse.com
- /etc/X11/xdm/SuSEconfig.xdm: copied required function from old
  /lib/YaST/SuSEconfig.functions, which no longer exists since
  openSUSE 12.3 (bnc#806738)
* Tue Jan  8 2013 sndirsch@suse.com
- /etc/X11/xdm/Keyboard.map:
  * added missing mac-dvorak entry (bnc#796170)
* Fri Dec  7 2012 werner@suse.de
- Be aware the mktemp(1) without XXXXXX will do exactly nothing,
  therefore use mv(1) which uses rename(2) on the same file system
  to use the files created by mktemp(1) to the log output file
* Mon Nov 19 2012 fcrozat@suse.com
- Add display-manager as provides to xdm initscript, to comply with
  systemd defaults.
* Thu Nov 15 2012 tittiatcoke@gmail.com
- Added a switch to enable building against systemd-logind and
  to remove the dependency on ConsoleKit
- Enabled the systemd switch already for Factory
* Tue Sep 25 2012 werner@suse.de
- Make failsafe work after a failed exec bash builtin
- Add dbus-launch and ck-launch-session to final session command
  line for case of using xdm
* Thu Sep 13 2012 sndirsch@suse.com
- add dependency on xtrans, otherwise TCP is not supported for
  xdmcp (bnc#780122)
* Thu Aug 16 2012 msrb@suse.cz
- separate *.fallback displaymanager files from xdm.tar.bz2 into
  xdm-fallbacks.tar.bz2 and build only suse version < 1210.
  (bnc#714003)
* Thu Aug 16 2012 msrb@suse.cz
- /etc/init.d/xdm: add plymouth_quit function, use it in xdm
  displaymanager file (bnc#775548)
* Tue Aug  7 2012 sndirsch@suse.com
- /etc/init.d/xdm: overwrite displaymanager's PIDFILE symlink if
  neccessary (bnc#774555)
* Sat Jun 30 2012 tiwai@suse.de
- avoid plymouth quit for kdm and gdm (bnc#762909)
* Fri Jun 29 2012 tiwai@suse.de
- remove --retain-splash option from plymouth quit (bnc#769209)
* Fri Jun 29 2012 sndirsch@suse.com
- /etc/init.d/xdm
  * quit plymouth properly before starting displaymanager
    (bnc#769209)
* Mon Jun 18 2012 werner@suse.de
- Skip LANG argument from command line of session managers (bnc#661946)
* Thu May 10 2012 sndirsch@suse.com
- /etc/pam.d/xdm-np: add session require to pam_loginuid.so in
  order to fix running commands via sudo (bnc #746704)
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xdm from xorg-x11. Initial version: 1.1.10.
